# Peek into how your application is working

This is a package that allows you to control aspects of your application without having to log onto a server.

Currently supported:
- Seeing current PHP / Laravel version
- What PHP extensions are loaded
- Is the site publicly accessible
- Which drivers are being used for cache, config, queues...etc
- Are the routes and config cached
- Viewing and editing `.env` file
- Browsing the storage logs
- Running a few artisan commands

## Installation

Add our composer repository to your `composer.json`:

```json
    ...
    "repositories": [
        {
            "type": "composer",
            "url": "http://composer.drp.digital"
        }
    ]
    ...
```

You can then install the package via composer:

```bash
$ composer require drp/peek
```

## Usage

If you are using Laravel >5.5 then you can skip this step.

Add the service provider to your `config/app.php`

``` php
...
\Drp\Peek\PeekServiceProvider::class
...
```

Next we need to publish the assets used by Peek. This will also add a config file to your project where you can configure a few options.

```bash
$ php artisan vendor:publish --provider="Drp\Peek\PeekServiceProvider"
```

#### Laravel Mix

If you are using Laravel Mix in your project and doing the versioning then make sure that the config option `using_mix` is set to true as this
will force Peek to then use the `mix()` helper instead of just the basic `url()` helper to get it's assets.

You will need to make sure the below code exists in your Laravel Mix webpack config:

```js
if (mix.inProduction()) {
  mix.version(['public/vendor/peek/app.css']);
}
```

### Testing

``` bash
composer test
```

### Changelog

Please see [CHANGELOG](CHANGELOG.md) for more information what has changed recently.

## Contributing

Please see [CONTRIBUTING](CONTRIBUTING.md) for details.

### Security

If you discover any security related issues, please email chris.normansell@drpgroup.com instead of using the issue tracker.

## Credits

- [Chris Normansell](https://git.drp.digital/cnormansell)

## License

The MIT License (MIT). Please see [License File](LICENSE.md) for more information.
